/**
 * MingerWorld <http://www.1ec5.org/3d/mingerworld/>
 * Last modified: 2008-01-26T01:20:12-08:00
 * Original content copyright (c) 2002-2008 Minh Nguyen. Some rights reserved
 * under the Creative Commons Attribution-ShareAlike 2.5 license. See
 * <http://creativecommons.org/licenses/by-sa/2.5/> for details.
 */

/**
 * Users of Builds 67 and earlier get a warning.
 */
var maxOldVersion = 0.67;

/**
 * Welcome text, shown at startup and when hovering over the MingerWorld logo
 * box.
 */
var intro = "MingerWorld\n" +
			"7 Community Square\n" +
			"Copyright (c) 2002-2008 Minh Nguyen. Some rights reserved under " +
			"the Creative Commons Attribution-ShareAlike 2.5 license.";
var projectUrl = "http://www.1ec5.org/3d/mingerworld/";

/**
 * Text that gets printed to the console when the user hovers over an object
 * with the given ID.
 */
var captions = {
	// Lobby
	"mingerworld-logo":
		intro,
	"gumby":
		"Snapshot of minger, wearing Gumby avatar, in Community World.\n" +
		"Gumby avatar is copyright (c) \"Lightfoot\". Gumby, Pokey, and " +
		"other Gumby characters are trademarks or registered trademarks of " +
		"Prema Toy Co. The images and sounds of Gumby, Pokey and other Gumby " +
		"characters are protected by copyrights owned by Premavision, Inc.",
	"minh":
		"Minh Nguyen",
	"poster-coming":
		"Coming Soon to MingerWorld:\n" +
		" - More pictures and exhibits\n" +
		" - More JavaScript effects\n" +
		" - Landscaping and floral decor\n",
	
	// Basement gallery
	"mozdev-logo":
		"Mozdev.org: A website allowing anyone to create addons for Mozilla.",
	"mozilla-dino":
		"Mozilla: An open-source, standards-compliant Internet application " +
		"suite.",
	"lsponline-logo":
		"LSP Online: A multi-school newspaper covering schools in the " +
		"Loveland, Ohio area.",
	"stxavier-front":
		"St. Xavier Magis: An alternative school newspaper serving St. " +
		"Xavier High School in Cincinnati, Ohio.",
	"xulos-logo":
		"Xulos: Free the Lizard! An effort to create an operating system UI " +
		"based on Mozilla technologies.",
	"jpen-galaxy":
		"Josh\'s Site of Completely Random Stuff: Created by a good friend " +
		"of mine, Josh Pendl. Randomness is a good thing, after all.",
	"Computer4":
		"Computer provided by and copyright (c) 2002 \"Knight\".",
	
	// Annex
	"egg":
		"Congratulations! You\'ve found it! The Easter egg! Click now!",
	
	// Ground floor gallery
	"frame01":	// exhibit/frame01
		"\"Lamp\"\n" +
		"Minh Nguyen, 2001",
	"frame02":
		"\"Watch the Time Go By\"\n" +
		"Pencil (HB)\n" +
		"Minh Nguyen, 2001",
	"frame03":
		"\"Lakeside\"\n" +
		"Pencil (HB)\n" +
		"Minh Nguyen, 2001",
	"frame04":
		"\"Archway to Fun\"\n" +
		"Pencil (HB)\n" +
		"Minh Nguyen, 2001",
	"frame05":
		"\"Park Sculpture\"\n" +
		"Pencil (HB)\n" +
		"Minh Nguyen, 2001",
	
	// Loft
	"Piano":
		"Piano object courtesy of and copyright (c) 2002 Martin Judd."
};

/**
 * URL that the user is taken to when clicking on a linked object.
 */
var links = {
	// Lobby
	"mingerworld-logo": projectUrl,
	"poster-coming": "http:/\/mxn.netfirms.com/projects/mingerworld/coming.html",
	
	// Basement gallery
	"mozdev-logo": "http:/\/www.mozdev.org/",
	"mozilla-dino": "http:/\/www.mozilla.org/",
	"lsponline-logo": "http:/\/lsponline.netfirms.com/",
	"stxavier-front": "http:/\/mxn.netfirms.com/magis/",
	"xulos-logo": "http:/\/mxn.netfirms.com/projects/xulos/",
	"jpen-galaxy": "http:/\/www.geocities.com/ccrunner311/mysite.html",
	
	// Annex
	"egg": "http:/\/mxn.netfirms.com/projects/mingerworld/egg.html"
};

/**
 * Warn users of old Atmosphere versions that certain features won't work.
 */
function mw_oldVersion() {
	chat.print("You are currently visiting this world using Adobe " +
			   "Atmosphere Player, version " + version + ". Version 0.91 " +
			   "of this software is now available, and is now required " +
			   "for many features in this world.");
//	var url = "http:/\/www.adobe.com/products/atmosphere/betaupdate.html";
	var url = "http:/\/en.wikipedia.org/wiki/Adobe_Atmosphere";
	chat.print("For more information, please visit <" + url + ">.\n");
}

/**
 * Add a panel for controlling the given sound to the Controls tab.
 */
function mw_addSoundControls(sound, name) {
	if (!hasModule("Button")) return;
	
	soundToggle = Toggle(name + " Sound").add();
	soundToggle.onClick = function (state) {
		sound.active = state;
	}
	soundToggle.state = true;
	
	soundVolume = Slider(name + " Volume").add();
	soundVolume.integersOnly = false;
	soundVolume.range = [0,1];
	soundVolume.onChange = function (val) {
		sound.volume = val;
	}
	soundVolume.value = sound.volume;
}

/**
 * Start ambient music from IBM Aptiva Guide.
 */
function mw_startMusic() {
	music = Sound("4MNU.WAV");
	music.volume = .36;
	music.repeats = 0;	// loop
	music.active = true;	// turn sound on
	
	mw_addSoundControls(music, "Background");
}

/**
 * Return an object with the given ID.
 */
function mw_getObjectById(objId) {
	return stageModel.getSolidObject(0).getPrimitive(objId);
}

/**
 * Add hoverable objects that print to the console and clickable objects that
 * lead to websites.
 */
function mw_addLinks() {
	captionHandler = MouseEventHandler();
	captionHandler.setFilterOnMouseOver(stageModel.getSolidObject(0));
	captionHandler.onEvent = function (mouseEvent, obj) {
		var msg = captions[obj.name];
		if (!msg) return;
		chat.print(msg);
		msg = links[obj.name];
		if (msg) chat.print("Click for <" + msg + ">.");
	}
	
	linkHandler = MouseEventHandler();
	linkHandler.setFilterOnClick(stageModel.getSolidObject(0));
	linkHandler.onEvent = function (mouseEvent, obj) {
		if (!links[obj.name]) return;
		sendJS("window.open('" + links[obj.name] + "', 'mw_external');");
	}
}

/**
 * Entry point for world JavaScript.
 */
function mw_start() {
	// Welcome the user
	chat.print(intro);
	chat.print(projectUrl);
	
	// Warn about old version of Atmosphere
	if (version <= maxOldVersion) {
		mw_oldVersion();
		return;
	}
	
	mw_startMusic();
	mw_addLinks();
}
mw_start();
